@@ -10,16 +10,16 @@ from lfc.utils.registration import unregister_template
 # lfc_contact_form import
 from lfc_contact_form.models import ContactForm
 
-name = _(u"Contact form")
+name = _(u"Contact Form")
 description = _(u"Contact form for LFC")
-version = u"1.0"
+version = u"1.0.1"
 
 
 def install():
     """Installs the lfc_contact_form application.
     """
     # Register Templates
-    register_template(name="Contact form", path="lfc_contact_form/contact_form.html")
+    register_template(name="Contact Form", path="lfc_contact_form/contact_form.html")
 
     # Register objects
     register_content_type(ContactForm, name="Contact", templates=["Contact Form"], default_template="Contact Form", global_addable=True, workflow="Portal")
@@ -32,4 +32,4 @@ def uninstall():
     unregister_content_type("ContactForm")
 
     # Unregister template
-    unregister_template("Contact form")
+    unregister_template("Contact Form")
